@@ -570,6 +570,9 @@ ee_store_recur_rule_to_ical (EventEditor *ee)
 			ical->recur->u.month_day =
 				gtk_spin_button_get_value_as_int (
 					GTK_SPIN_BUTTON (ee->recur_rr_month_date));
+			ical->recur->interval =
+				gtk_spin_button_get_value_as_int (
+					GTK_SPIN_BUTTON (ee->recur_rr_month_period));
 		} else {
 			/* by position */
 
@@ -577,7 +580,7 @@ ee_store_recur_rule_to_ical (EventEditor *ee)
 
 			ical->recur->u.month_pos =
 				option_menu_active_number (ee->recur_rr_month_day);
-			ical->recur->u.month_day =
+			ical->recur->weekday =
 				option_menu_active_number (ee->recur_rr_month_weekday);
 			ical->recur->interval =
 				gtk_spin_button_get_value_as_int (
@@ -1011,7 +1014,7 @@ ee_rp_init_rule (EventEditor *ee)
 			page = 3;
 			month_period = interval;
 			def_pos = ee->ical->recur->u.month_pos;
-			default_day = ee->ical->recur->u.month_day;
+			default_day = ee->ical->recur->weekday; /* you can't use u.month_pos and u.month_day-- it's a union... */
 			break;
 
 		case RECUR_MONTHLY_BY_DAY:
@@ -1282,7 +1285,7 @@ get_exception_string (time_t t)
 {
 	static char buf[256];
 
-	strftime (buf, sizeof(buf), "%a %b %d %Y", localtime (&t)); /* FIXME: how to i18n this? */
+	strftime (buf, sizeof(buf), _("%a %b %d %Y"), localtime (&t));
 	return buf;
 }
 
