@@ -1319,10 +1319,11 @@ card_convert_to_vobject(Card *crd)
 		
 		for (node = crd->phone.l; node; node = node->next) {
 			CardPhone *phone = (CardPhone *) node->data;
-			
+
 			if (phone->prop.used) {
-				vprop = add_strProp(vobj, VCTelephoneProp, 
-						    phone->data);
+				vprop = add_strProp(vobj, VCTelephoneProp,
+						    (phone->data)? 
+						     phone->data: "");
 				add_PhoneType(vprop, phone->type);
 				add_CardProperty(vprop, &phone->prop);
 			}
