@@ -56,7 +56,7 @@ getColumnNameFromType(ColumnType type)
 	if (column_hdrs[i].coltype == type)
 	    break;
 
-    return column_hdrs[i].colname;
+    return _(column_hdrs[i].colname);
 }
 
 gchar *
@@ -91,7 +91,7 @@ getColumnTypeFromName(gchar *name)
     gint i;
 
     for (i=0; column_hdrs[i].colname; i++)
-	if (!strcmp(column_hdrs[i].colname, name))
+	if (!strcmp(_(column_hdrs[i].colname), name))
 	    break;
 
     return column_hdrs[i].coltype;
@@ -107,7 +107,7 @@ getColumnHdrFromType(ColumnType type)
 	if (column_hdrs[i].coltype == type)
 	    break;
 
-    return (column_hdrs[i].colname) ? &column_hdrs[i] : NULL;
+    return _(column_hdrs[i].colname) ? &column_hdrs[i] : NULL;
 }
 
 
