@@ -38,10 +38,7 @@ gnomecard_delete_current_card(GtkWidget *widget, gpointer data)
 {
     GList *tmp;
 
-    if (!gnomecard_curr_crd) {
-	g_message("in delete_current_card, no current card!");
-	return;
-    }
+    g_return_if_fail (gnomecard_curr_crd != NULL);
 
     if (gnomecard_curr_crd->next)
 	tmp = gnomecard_curr_crd->next;
@@ -57,7 +54,8 @@ gnomecard_delete_current_card(GtkWidget *widget, gpointer data)
 	gnomecard_scroll_list(tmp);
     else
 	gnomecard_set_curr(NULL);
-
+	
+    gnomecard_set_changed (TRUE);
 }
 
 
