@@ -20,9 +20,10 @@
  */
 
 #include <config.h>
-#include <fnmatch.h>
 #include <gnome.h>
 
+#include <fnmatch.h>
+
 #include "card.h"
 #include "canvas.h"
 #include "dialog.h"
@@ -34,6 +35,7 @@
 #include "addresslist.h"
 #include "phonelist.h"
 #include "world.xpm"
+#include "misc.h"
 
 typedef struct {
     GtkWidget *srcList;
@@ -100,9 +102,6 @@ gchar *email_type_name[] =
 		               N_("MCI"), N_("Power Share"), N_("Prodigy"), N_("TLX"),
 		               N_("X400"), NULL };
 
-
-
-
 /* handle when the user applies changes to the card editor propertybox */
 static void gnomecard_prop_apply(GtkWidget *widget, int page)
 {
@@ -1387,9 +1386,32 @@ extern void gnomecard_edit_card(GtkWidget *widget, gpointer data)
 extern gboolean gnomecard_append_file(char *fname)
 {
 	GList *crds;
-
-	if (!(crds = card_load(gnomecard_crds, fname)))
-	  return FALSE;
+	char *real_fname;
+	char *app_title;
+	char *fmt;
+	
+	if (! *fname)
+	  real_fname = misc_tilde_expand ("~/.gnome/GnomeCard.gcrd");
+	else
+	  real_fname = fname;
+	
+	if (!(crds = card_load(gnomecard_crds, real_fname))) {
+		if (! *fname)
+		  g_free (real_fname);
+		
+		return FALSE;
+	}
+	
+	if (! *fname) {
+		g_free (real_fname);
+		real_fname = _("Default");
+	}
+	
+	fmt = _("GnomeCard: %s");
+	app_title = g_malloc (strlen (fmt) + strlen (real_fname));
+	sprintf (app_title, fmt, real_fname);
+	gnomecard_set_app_title (app_title);
+	g_free (app_title);
 	
 	gnomecard_crds = crds;
 	gnomecard_sort_card_list_by_default();
@@ -1399,19 +1421,38 @@ extern gboolean gnomecard_append_file(char *fname)
 	return TRUE;
 }
 
-static void gnomecard_send_read_error(char *fname)
+static void gnomecard_send_error(char *fname, char *action)
 {
 	GtkWidget *w;
-	char *tmp;
+	char *message, *fmat;
+	char *real_fname;
 	
-	tmp = g_malloc(strlen(_("Error reading file.")) + strlen(fname) + 3);
-	sprintf(tmp, "%s: %s", fname, _("Error reading file."));
-	w = gnome_message_box_new(tmp,
+	if (! *fname)
+	  real_fname = _("the default file");
+	else
+	  real_fname = fname;
+	
+	fmat = _("Error %s %s.");
+	
+	message = g_malloc (strlen (fmat) + strlen (action) + 
+			    strlen (real_fname));
+	sprintf (message, fmat, action, real_fname);
+	w = gnome_message_box_new(message,
 				  GNOME_MESSAGE_BOX_ERROR,
 				  GNOME_STOCK_BUTTON_OK, NULL);
 	GTK_WINDOW(w)->position = GTK_WIN_POS_MOUSE;
 	gtk_widget_show(w);
-	g_free(tmp);
+	g_free (message);
+}
+
+static void gnomecard_send_read_error (char *fname)
+{
+	gnomecard_send_error (fname, "reading");
+}
+
+static void gnomecard_send_write_error (char *fname)
+{
+	gnomecard_send_error (fname, "writing");
 }
 
 static void gnomecard_append_call(GtkWidget *widget, gpointer data)
@@ -1483,13 +1524,23 @@ extern void gnomecard_open(GtkWidget *widget, gpointer data)
 	gtk_widget_show(fsel);
 }
 
+extern void gnomecard_open_default (GtkWidget *widget, gpointer data)
+{
+	if (gnomecard_open_file("")) {
+		g_free(gnomecard_fname);
+		gnomecard_fname = g_strdup("");
+		gnome_config_set_string("/GnomeCard/file/open",  gnomecard_fname);
+	}
+}
+
 static void gnomecard_save_call(GtkWidget *widget, gpointer data)
 {
 	g_free(gnomecard_fname);
 	gnomecard_fname = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(widget)));
 	gtk_widget_destroy(widget);
 	
-	gnomecard_save();
+	if (gnomecard_save() == -1)
+	  gnomecard_send_write_error (gnomecard_fname);
 }
 
 extern void gnomecard_save_as(GtkWidget *widget, gpointer data)
