@@ -24,9 +24,13 @@
 #include <libgnorba/gnorba.h>
 #include <string.h>
 #include <time.h>
+#include <errno.h>
+#include <unistd.h>
+#include <sys/stat.h>
 
 #include <glib.h>
 #include <stdio.h>
+#include <orb/orbit.h>
 
 #include "../libversit/vcc.h"
 #include "card.h"
@@ -38,9 +42,9 @@
 #include "my.h"
 #include "sort.h"
 #include "list.h"
-#include <orb/orbit.h>
+#include "misc.h"
 
-#include "columnhdrs.h" /* only used because I'm hardcoding col hdrs 4 now */
+#include "columnhdrs.h"
 
 #define NAME_COL_WIDTH 100
 #define ORG_COL_WIDTH 100
@@ -107,8 +111,6 @@ Exception (CORBA_Environment * ev)
     }
 }
 
-
-
 gchar
 *gnomecard_join_name (char *pre, char *given, char *add, char *fam, char *suf)
 {
@@ -131,6 +133,11 @@ gchar
     return name;
 }
 
+void gnomecard_set_app_title (char *title) 
+{
+	gtk_window_set_title (GTK_WINDOW (gnomecard_window), title);
+}
+
 void
 gnomecard_set_changed(gboolean val)
 {
@@ -231,17 +238,68 @@ gnomecard_set_curr(GList *node)
     }
 }
 
-extern void gnomecard_save(void)
+extern gboolean gnomecard_save(void)
 {
 	GList *l;
 	FILE *fp;
+	char *bak_fname, *bak_fname2, *cmd, *real_fname;
+	struct stat s;
+	char i;
+	
+	if (! *gnomecard_fname)
+	  real_fname = misc_tilde_expand ("~/.gnome/GnomeCard.gcrd");
+	else
+	  real_fname = gnomecard_fname;
+	
+	bak_fname = g_malloc (strlen (real_fname) + 3);
+	
+	for (i = '0'; i <= '9'; i++) {
+		
+		bak_fname2 = g_strdup (bak_fname);
+		sprintf (bak_fname, "%s~%c", real_fname, i);
+		
+		if (stat (bak_fname, &s) == -1 && errno == ENOENT) {
+			g_free (bak_fname2);
+			break;
+		}
+		
+		if (i != '0') {
+			cmd = g_malloc (strlen (bak_fname) + 
+					strlen (bak_fname2) + 8);
+		
+			sprintf (cmd, "mv -f %s %s", bak_fname, bak_fname2);
+			
+			system (cmd);
+			g_free (cmd);
+			g_free (bak_fname2);
+		}
+	}
+	
+	cmd = g_malloc (strlen (bak_fname) + strlen (real_fname) + 8);
+	sprintf (cmd, "cp -f %s %s", real_fname, bak_fname);
+	system (cmd);
+	
+	g_free (cmd);
+	g_free (bak_fname);
 
-	fp = fopen (gnomecard_fname, "w");
-	for (l = gnomecard_crds; l; l= l->next)
+	fp = fopen (real_fname, "w");
+	if (! fp) {
+		if (! *gnomecard_fname)
+		  g_free (real_fname);
+		
+		return FALSE;
+	}
+	
+	for (l = gnomecard_crds; l; l = l->next)
 	  card_save((Card *) l->data, fp);
 	fclose(fp);
 	
 	gnomecard_set_changed(FALSE);
+	
+	if (! *gnomecard_fname)
+	  g_free (real_fname);
+		
+	return TRUE;
 }
 
 static gboolean
@@ -276,8 +334,14 @@ extern int gnomecard_destroy_cards(void)
     if (gnomecard_changed) {
 	GtkWidget *w;
 	char *msg;
+	char *real_fname;
 	
-	msg= g_strconcat (gnomecard_fname, _(" changed. Save?"), NULL);
+	if (! *gnomecard_fname)
+	  real_fname = _("The default file");
+	else
+	  real_fname = gnomecard_fname;
+	    
+	msg= g_strconcat (real_fname, _(" changed. Save?"), NULL);
 	
 	w = gnome_message_box_new(msg,
 				  GNOME_MESSAGE_BOX_QUESTION,
@@ -398,12 +462,17 @@ GnomeUIInfo filemenu[] = {
 
 	GNOMEUIINFO_MENU_OPEN_ITEM(gnomecard_open, NULL),
 
+	{GNOME_APP_UI_ITEM, N_("Open _Default"),
+	 N_("Open the default file"),
+	 gnomecard_open_default, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
+	
 	GNOMEUIINFO_MENU_SAVE_ITEM(gnomecard_save, NULL),
 
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM(gnomecard_save_as, NULL),
 
 	{GNOME_APP_UI_ITEM, N_("_Append..."),
-	 N_("Add the contents of another Card File."),
+	 N_("Add the contents of another card file"),
 	 gnomecard_append, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
 
@@ -463,11 +532,15 @@ GnomeUIInfo sortmenu[] = {
 };
 
 GnomeUIInfo editmenu[] = {
-	{GNOME_APP_UI_ITEM, N_("Card"), N_("Edit card"),
+	{GNOME_APP_UI_ITEM, N_("Add"), N_("Create new card"),
+	 gnomecard_new_card, NULL, NULL,
+	GNOME_APP_PIXMAP_STOCK, "GnomeCardNewMenu", 0, 0, NULL},
+	
+	{GNOME_APP_UI_ITEM, N_("Modify"), N_("Edit card"),
 	 gnomecard_edit_card, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, "GnomeCardEditMenu", 0, 0, NULL},
 	
-	{GNOME_APP_UI_ITEM, N_("Delete"), N_("Delete element"),
+	{GNOME_APP_UI_ITEM, N_("Delete"), N_("Erase card"),
 	 gnomecard_delete_current_card, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE, 0, 0, NULL},
 	
@@ -573,7 +646,7 @@ GnomeUIInfo toolbar[] = {
 	 gnomecard_new_card, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, "GnomeCardNew", 0, 0, NULL},
 	
-	{GNOME_APP_UI_ITEM, N_("Edit"), N_("Edit card"),
+	{GNOME_APP_UI_ITEM, N_("Modify"), N_("Edit card"),
 	 gnomecard_edit_card, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, "GnomeCardEdit", 0, 0, NULL},
 	
@@ -630,15 +703,15 @@ void gnomecard_init(void)
 	gnomecard_init_stock();
 	gnomecard_init_pixes();
 	
-	gnomecard_window = GNOME_APP(gnome_app_new("gnomecard", "gnomecard"));
+	gnomecard_window = GNOME_APP(gnome_app_new("GnomeCard", "GnomeCard: Default"));
 
 	appbar = GNOME_APPBAR(gnome_appbar_new(FALSE, TRUE,
 					       GNOME_PREFERENCES_USER));
 	gnome_app_set_statusbar(GNOME_APP(gnomecard_window),
 				GTK_WIDGET(appbar));
 
-	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "gnomecard",
-			       "gnomecard");
+	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "GnomeCard",
+			       "GnomeCard");
 	gtk_window_set_policy(GTK_WINDOW(gnomecard_window), TRUE, TRUE, TRUE);
 			      
 	gtk_signal_connect(GTK_OBJECT(gnomecard_window), "delete_event",
@@ -735,10 +808,10 @@ void gnomecard_init(void)
 	tb_last = toolbar[10].widget;
 	tb_find = toolbar[12].widget;
 	
-	menu_save = filemenu[2].widget;
-	menu_edit = editmenu[0].widget;
-	menu_del  = editmenu[1].widget;
-	menu_find = editmenu[5].widget;
+	menu_save = filemenu[3].widget;
+	menu_edit = editmenu[1].widget;
+	menu_del  = editmenu[2].widget;
+	menu_find = editmenu[6].widget;
 	menu_first = gomenu[0].widget;
 	menu_prev = gomenu[1].widget;
 	menu_next = gomenu[2].widget;
